@@ -24,6 +24,7 @@ salsa - tool to manipulate salsa repositories and group members
   salsa add_user developer foobar --group-id 2665
   salsa update_user maintainer foobar --group js-team
   salsa del_user foobar --group js-team
+  salsa last_ci_status js-team/nodejs
 
 =head1 DESCRIPTION
 
@@ -60,6 +61,14 @@ contains:
 
 =over
 
+=item B<join>
+
+Request access to a group.
+
+  salsa join js-team
+  salsa join --group js-team
+  salsa join --group-id 1234
+
 =item B<add_user>
 
 Add a user to a group.
@@ -199,6 +208,32 @@ List forks of project(s).
 Project can be set using full path or using B<--group>/B<--group-id> or
 B<--user>/B<--user-id>, else it is searched in current user namespace.
 
+=item B<push>
+
+Push relevant packaging refs to origin Git remote. To be run from packaging
+working directory.
+
+  salsa push
+
+It pushes the following refs to the configured remote for the debian-branch or,
+falling back, to the "origin" remote:
+
+=over
+
+=item "master" branch (or whatever is set to debian-branch in gbp.conf)
+
+=item "upstream" branch (or whatever is set to upstream-branch in gbp.conf)
+
+=item "pristine-tar" branch
+
+=item tags named "debian/*" (or whatever is set to debian-tag in gbp.conf)
+
+=item tags named "upstream/*" (or whatever is set to upstream-tag in gbp.conf)
+
+=item all tags, if the package's source format is "3.0 (native)"
+
+=back
+
 =item B<ls> or B<list_repos>
 
 Shows projects owned by user or group. If second
@@ -207,6 +242,22 @@ argument exists, search only matching projects
   salsa --group js-team list_repos
   salsa --user yadd list_repos foo*
 
+=item B<last_ci_status> or B<ci>
+
+Displays last continuous integration result. Use B<--verbose> to see
+URL of pipeline when result isn't B<success>. Unless B<--no-fail> is set,
+B<salsa last_ci_status> will stop on first "failed" status.
+
+  salsa --group js-team last_ci_status --all --no-fail
+  salsa --user yadd last_ci_status foo
+  salsa last_ci_status js-team/nodejs
+
+This commands returns the number of "failed" status found. "success" entries
+are displayed using STDOUT while other are displayed I<(with details)> using
+STDERR. Then you can easily see only failures using:
+
+  salsa --group js-team last_ci_status --all --no-fail >/dev/null
+
 =item B<merge_request>, B<mr>
 
 Creates a merge request.
@@ -448,8 +499,17 @@ or
 
   alias jsteam_admin="salsa --conf-file ~/.js.conf
 
+or to use both .devscripts and .js.conf:
+
+  alias jsteam_admin="salsa --conf-file +~/.js.conf
+
 then you can fix B<SALSA_GROUP> in C<~/.js.conf>
 
+To enable bash completion for your alias, add this in your .bashrc file:
+
+  _completion_loader salsa
+  complete -F _salsa_completion jsteam_admin
+
 =item B<--group-id>
 
 Group id to use. Use C<salsa search_group name> to find it.
@@ -517,6 +577,20 @@ C<.devscripts> value: B<SALSA_YES> (yes/no)
 
 =back
 
+=head2 List/search repo options
+
+=over
+
+=item B<--archived> B<--no-archived>
+
+Instead of looking to active projects, list or search in archived projects.
+Note that you can't have both archived and unarchived projects in the same
+request. Default: no I<(ie --no-archived)>.
+
+C<.devscripts> value: B<SALSA_ARCHIVED> (yes/no)
+
+=back
+
 =head2 Update/create repo options
 
 =over
@@ -548,7 +622,7 @@ C<.devscripts> value: B<SALSA_SKIP_FILE>
 
 Configure configuration file path of GitLab CI. Default: empty. Example:
 
-  salsa update_safe --ci-config-path debian/.gitlab-ci.yml debian/devscripts
+  salsa update_safe --ci-config-path recipes/debian.yml@salsa-ci-team/pipeline debian/devscripts
 
 C<.devscripts> value: B<SALSA_CI_CONFIG_PATH>
 
@@ -642,7 +716,7 @@ C<.devscripts> value: B<SALSA_KGB> (yes/ignore/no, default: ignore)
 
 List of KGB enabled options (comma separated). Default: issues_events,
 merge_requests_events, note_events, pipeline_events, push_events,
-tag_push_events, wiki_page_events
+tag_push_events, wiki_page_events, enable_ssl_verification
 
   $ salsa update_safe debian/devscripts --kgb --irc-channel devscripts \
     --kgb-options 'merge_requests_events,issues_events,enable_ssl_verification'
